Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Hop ¶
type Hop struct {
//TODO: add more
InterfaceRef *string
Index *string
NextHop gnmitargetygot.OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union
}
type IPAddress ¶
IPAddress represents a IPv4 or Ipv6 address in the context of a osclient. NOTE: (maba) will probably be extended
type Interface ¶
type Interface struct {
Index *uint32
Name *string
Type gnmitargetygot.E_IETFInterfaces_InterfaceType
MTU *uint16
OperState gnmitargetygot.E_OpenconfigInterfaces_Interfaces_Interface_State_OperStatus
AdminStatus gnmitargetygot.E_OpenconfigInterfaces_Interfaces_Interface_State_AdminStatus
LoopbackMode *bool
Ipv4Addresses []IPAddress
Ipv6Addresses []IPAddress
}
NOTE: these extra structs are probably not necessary and it would be smarter to just use the ygot generated structs internally aswell. This would prevent passing information through multiple structs.
type Interfaces ¶
type Interfaces interface {
GetInterfaces() ([]*Interface, error)
SetInterface(*Interface) error
SubscribeToInterfaces() (chan *Interface, error)
}
func NewInterfaces ¶
func NewInterfaces() Interfaces
type NetworkInstances ¶
type NetworkInstances interface {
SetStaticRoute(*StaticRoute) error
GetStaticRoutes(linkName string) ([]*StaticRoute, error)
}
func NewNetworkInstances ¶
func NewNetworkInstances() NetworkInstances
type StaticRoute ¶
type System ¶
type System interface {
GetHostname() (string, error)
SetHostname(hostname *string) error
GetCurrentTime() time.Time
GetTimeZoneName() string
GetTotalMemory() uint64
GetFreeMemory() uint64
GetUsedMemory() uint64
GetDomainName() (string, error)
GetMotd() (string, error)
SetMotd(message string) error
// yang: leaf software-version
GetSoftwareVersion() (string, error)
}
Click to show internal directories.
Click to hide internal directories.